@@ -2,10 +2,10 @@
 Utility functions
 """
 
-from distutils.util import strtobool
+import re
 from os import getcwd
 from os import getenv as getenv_
-from os import path
+from os import listdir, path
 from pathlib import Path
 from platform import machine
 from shutil import which
@@ -14,9 +14,15 @@ from types import GeneratorType
 
 import click
 from dotenv import set_key, unset_key
+from dotenv.main import dotenv_values
 
 from brewblox_ctl import const
 
+# Matches API of distutils.util.strtobool
+# https://docs.python.org/3/distutils/apiref.html#distutils.util.strtobool
+TRUE_PATTERN = re.compile('^(y|yes|t|true|on|1)$', re.IGNORECASE)
+FALSE_PATTERN = re.compile('^(n|no|f|false|off|0)$', re.IGNORECASE)
+
 
 class ContextOpts:
 
@@ -37,13 +43,21 @@ def ctx_opts():
     return click.get_current_context().find_object(ContextOpts)
 
 
+def strtobool(val):
+    if re.match(TRUE_PATTERN, val):
+        return True
+    if re.match(FALSE_PATTERN, val):
+        return False
+    raise ValueError()
+
+
 def confirm(question, default=True):
     default_val = 'yes' if default else 'no'
     prompt = "{} [Press ENTER for default value '{}']".format('{}', default_val)
     click.echo(prompt.format(question))
     while True:
         try:
-            return bool(strtobool(input().lower() or str(default)))
+            return strtobool(input() or default_val)
         except ValueError:
             click.echo("Please type 'y(es)' or 'n(o)' and press ENTER.")
 
@@ -148,6 +162,17 @@ def is_brewblox_cwd():
     return bool(getenv(const.CFG_VERSION_KEY))
 
 
+def is_brewblox_dir(dir):
+    env_path = dir + '/.env'
+    if not path.isfile(env_path):
+        return False
+    return const.CFG_VERSION_KEY in dotenv_values(env_path)
+
+
+def is_empty_dir(dir):
+    return path.isdir(dir) and not listdir(dir)
+
+
 def optsudo():
     return 'sudo ' if not is_docker_user() else ''
 
